@@ -1,4 +1,4 @@
-"""Exceptions definitions."""
+"""Landroid Cloud exception definitions."""
 from __future__ import annotations
 
 
@@ -30,6 +30,10 @@ class RequestException(Exception):
     """Define a request exception."""
 
 
+class MQTTException(Exception):
+    """Define a MQTT exception."""
+
+
 # Exception classes for URL requests
 class RequestError(Exception):
     """Define a bad request error (400)."""
@@ -47,6 +51,10 @@ class NotFoundError(Exception):
     """Represents a not found error (404)."""
 
 
+class TooManyRequestsError(Exception):
+    """Represents a error when request quota have been exceeded (429)."""
+
+
 class InternalServerError(Exception):
     """Represents an internal server error (500)."""
 
